@@ -1,4 +1,4 @@
-# Copyright 2020 QuantumBlack Visual Analytics Limited
+# Copyright 2021 QuantumBlack Visual Analytics Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -39,6 +39,7 @@ import pyarrow as pa
 import pyarrow.parquet as pq
 
 from kedro.io.core import (
+    HTTP_PROTOCOLS,
     AbstractVersionedDataSet,
     DataSetError,
     Version,
@@ -124,6 +125,8 @@ class ParquetDataSet(AbstractVersionedDataSet):
         _credentials = deepcopy(credentials) or {}
 
         protocol, path = get_protocol_and_path(filepath, version)
+        if protocol == "file":
+            _fs_args.setdefault("auto_mkdir", True)
 
         self._protocol = protocol
         self._fs = fsspec.filesystem(self._protocol, **_credentials, **_fs_args)
@@ -180,6 +183,8 @@ class ParquetDataSet(AbstractVersionedDataSet):
                 f"Saving {self.__class__.__name__} to a directory is not supported."
             )
 
+        if self._protocol not in HTTP_PROTOCOLS:
+            self._fs.makedirs(Path(save_path).parent.as_posix(), exist_ok=True)
         table = pa.Table.from_pandas(data, **self._from_pandas_args)
         pq.write_table(
             table=table, where=save_path, filesystem=self._fs, **self._save_args
