@@ -34,12 +34,8 @@ import pickle
 import uuid
 from typing import Any, Dict, List
 
-from pyspark.sql import DataFrame, SparkSession  # pylint: disable=import-error
-from pyspark.sql.functions import (  # pylint: disable=import-error,no-name-in-module
-    coalesce,
-    col,
-    lit,
-)
+from pyspark.sql import DataFrame, SparkSession
+from pyspark.sql.functions import coalesce, col, lit
 
 from kedro.io.core import AbstractDataSet, DataSetError
 
