@@ -50,8 +50,7 @@ from kedro.versioning import Journal
 
 
 def _deprecate(version):
-    """Decorator to deprecate a few of the context's properties
-    """
+    """Decorator to deprecate a few of the context's properties."""
 
     def decorator(func):
         @functools.wraps(func)
@@ -290,7 +289,7 @@ class KedroContext:
         """
         try:
             return pipelines["__default__"]
-        except (TypeError, KeyError) as exc:  # pragma: no cover
+        except KeyError as exc:  # pragma: no cover
             raise KedroContextError(
                 "Failed to find the pipeline named '__default__'. "
                 "It needs to be generated and returned "
@@ -397,7 +396,7 @@ class KedroContext:
             feed_dict=feed_dict,
             save_version=save_version,
             load_versions=load_versions,
-            run_id=self.run_id,
+            run_id=self.run_id or save_version,
         )
         return catalog
 
@@ -431,8 +430,12 @@ class KedroContext:
             str(self.project_path / conf_root / self.env),
         ]
         hook_manager = get_hook_manager()
-        config_loader = hook_manager.hook.register_config_loader(  # pylint: disable=no-member
-            conf_paths=conf_paths, env=self.env, extra_params=self._extra_params,
+        config_loader = (
+            hook_manager.hook.register_config_loader(  # pylint: disable=no-member
+                conf_paths=conf_paths,
+                env=self.env,
+                extra_params=self._extra_params,
+            )
         )
         if not isinstance(config_loader, ConfigLoader):
             raise KedroContextError(
@@ -598,7 +601,7 @@ class KedroContext:
 
         try:
             pipeline = pipelines[name]
-        except (TypeError, KeyError) as exc:
+        except KeyError as exc:
             raise KedroContextError(
                 f"Failed to find the pipeline named '{name}'. "
                 f"It needs to be generated and returned "
