@@ -169,13 +169,13 @@ class KedroSession:
             save_on_close: Whether or not to save the session when it's closed.
             env: Environment for the KedroContext.
             extra_params: Optional dictionary containing extra project parameters
-            for underlying KedroContext. If specified, will update (and therefore take
-            precedence over) the parameters retrieved from the project configuration.
+                for underlying KedroContext. If specified, will update (and therefore
+                take precedence over) the parameters retrieved from the project
+                configuration.
 
         Returns:
             A new ``KedroSession`` instance.
         """
-        # pylint: disable=protected-access
 
         # this is to make sure that for workflows that manually create session
         # without going through one of our known entrypoints, e.g. some plugins like kedro-airflow,
@@ -191,7 +191,7 @@ class KedroSession:
             save_on_close=save_on_close,
         )
 
-        # have to explicity type session_data otherwise mypy will complain
+        # have to explicitly type session_data otherwise mypy will complain
         # possibly related to this: https://github.com/python/mypy/issues/1430
         session_data: Dict[str, Any] = {
             "package_name": session._package_name,
@@ -360,7 +360,7 @@ class KedroSession:
 
         try:
             pipeline = pipelines[name]
-        except (TypeError, KeyError) as exc:
+        except KeyError as exc:
             raise KedroContextError(
                 f"Failed to find the pipeline named '{name}'. "
                 f"It needs to be generated and returned "
