@@ -76,7 +76,7 @@ class PartitionedDataSet(AbstractDataSet):
         >>>
         >>> data_set = PartitionedDataSet(
         >>>     path="s3://bucket-name/path/to/folder",
-        >>>     dataset="CSVDataSet",
+        >>>     dataset="pandas.CSVDataSet",
         >>>     credentials=credentials
         >>> )
         >>> loaded = data_set.load()
@@ -264,6 +264,8 @@ class PartitionedDataSet(AbstractDataSet):
             # join the protocol back since tools like PySpark may rely on it
             kwargs[self._filepath_arg] = self._join_protocol(partition)
             dataset = self._dataset_type(**kwargs)  # type: ignore
+            if callable(partition_data):
+                partition_data = partition_data()
             dataset.save(partition_data)
         self._invalidate_caches()
 
@@ -313,7 +315,7 @@ class IncrementalDataSet(PartitionedDataSet):
         >>>
         >>> data_set = IncrementalDataSet(
         >>>     path="s3://bucket-name/path/to/folder",
-        >>>     dataset="CSVDataSet",
+        >>>     dataset="pandas.CSVDataSet",
         >>>     credentials=credentials
         >>> )
         >>> loaded = data_set.load()  # loads all available partitions
@@ -447,8 +449,10 @@ class IncrementalDataSet(PartitionedDataSet):
     @cachedmethod(cache=operator.attrgetter("_partition_cache"))
     def _list_partitions(self) -> List[str]:
         checkpoint = self._read_checkpoint()
-        checkpoint_path = self._filesystem._strip_protocol(  # pylint: disable=protected-access
-            self._checkpoint_config[self._filepath_arg]
+        checkpoint_path = (
+            self._filesystem._strip_protocol(  # pylint: disable=protected-access
+                self._checkpoint_config[self._filepath_arg]
+            )
         )
 
         def _is_valid_partition(partition) -> bool:
